.. _userdoc_api-documentation:

API documentation
#################

The API documentation gives details on how the additional *functions* and classes can be
used.

.. toctree::
   :maxdepth: 2

   core
   lib
